=========
up-consul
=========

Limited functionality Consul Python client to interact with the consul API.

Provides limited functionality for getting and setting values.

Release Notes:
==============


[0.0.2] - 2025-07-07
--------------------

Added:
    - url_scheme parameter, allowing http connections.


[0.0.1] - 2024-10-08
--------------------

Added:
    - ConsulClient connects to consul host using a requests session.
    - KVClient, for getting and settings values in the key-value storage.
